elliptic_curves: Databases of elliptic curves
=============================================

Description
-----------

Includes two databases:

-  A small subset of John Cremona's database of elliptic curves up
   to conductor 10000.

-  William Stein's database of interesting curves


Upstream Contact
----------------

cremona_mini
~~~~~~~~~~~~

-  Author: John Cremona
-  Email: john.cremona@gmail.com
-  Website: http://johncremona.github.io/ecdata/

ellcurves
~~~~~~~~~

-  Author: William Stein
-  Email: wstein@gmail.com

